#-*- coding:utf-8 -*-
#python 3.8
import sys, os, base64, datetime, hashlib, hmac 
import requests # python3 -m pip install requests
import urllib
import json

SERVICE_API = 'https://onepass.api.ksyun.com/'

#ak sk
ACCESS_KEY = ''
SECRET_KEY = ''

if ACCESS_KEY is None or SECRET_KEY is None:
    print('No access key is available.')
    sys.exit()

#generate sign
def sign(params, secret_key):
    str_encode = ''
    param_keys = sorted(params.keys())
    for key in param_keys:
        str_encode += urllib.request.quote(key,'~') + '=' + urllib.request.quote(str(params[key]),'~') + '&'
    print(str_encode[:-1])

    bytes_key = bytes(secret_key, encoding='utf-8')
    return hmac.new(bytes_key, str_encode[:-1].encode("utf-8"), hashlib.sha256).hexdigest()

#公共参数
def makeSysParams(ak):
    t = datetime.datetime.utcnow()
    sys_params = {
        'Accesskey' : ak,
        'Timestamp' : t.strftime('%Y-%m-%dT%H:%M:%SZ'),
        'Service'   : 'onepass',
        'Version'   : '2019-05-01',
        'SignatureVersion' : '1.0',
        'SignatureMethod'  : 'HMAC-SHA256',
        'Region'    : 'cn-beijing-6',
    }
    return sys_params

# 一键登录
# https://docs.ksyun.com/documents/37018
def mobileQuery(appId, token):
    parameters = makeSysParams(ACCESS_KEY)
    parameters['Action']    = 'MobileQuery'
    parameters['AppId']     = appId 
    parameters['Token']     = token
    parameters['Signature'] = sign(parameters, SECRET_KEY)

    print('\nBEGIN REQUEST++++++++++++++++++++++++++++++++++++')
    print('Request URL = ' + SERVICE_API)

    headers = {'accept':'application/json',
            'content-type':'application/x-www-form-urlencoded'}
    r = requests.post(SERVICE_API, data=parameters, headers=headers)

    print('\nRESPONSE++++++++++++++++++++++++++++++++++++')
    print('Response code: %d\n' % r.status_code)
    print(r.text)

# 号码认证
# https://docs.ksyun.com/documents/37080
def mobileValidate(appId, token, mobile):
    parameters = makeSysParams(ACCESS_KEY)
    parameters['Action']    = 'MobileValidate'
    parameters['AppId']     = appId 
    parameters['Token']     = token
    parameters['Mobile']    = mobile 
    parameters['Signature'] = sign(parameters, SECRET_KEY)

    print('\nBEGIN REQUEST++++++++++++++++++++++++++++++++++++')
    print('Request URL = ' + SERVICE_API)

    headers = {'accept':'application/json',
            'content-type':'application/x-www-form-urlencoded'}
    r = requests.post(SERVICE_API, data=parameters, headers=headers)

    print('\nRESPONSE++++++++++++++++++++++++++++++++++++')
    print('Response code: %d\n' % r.status_code)
    print(r.text)

# 号码认证(H5 小程序）
# https://docs.ksyun.com/documents/37549
def mobileWebValidate(appId, token, mobile):
    parameters = makeSysParams(ACCESS_KEY)
    parameters['Action']    = 'MobileWebValidate'
    parameters['AppId']     = appId 
    parameters['Token']     = token
    parameters['Mobile']    = mobile 
    parameters['Signature'] = sign(parameters, SECRET_KEY)

    print('\nBEGIN REQUEST++++++++++++++++++++++++++++++++++++')
    print('Request URL = ' + SERVICE_API)

    headers = {'accept':'application/json',
            'content-type':'application/x-www-form-urlencoded'}
    r = requests.post(SERVICE_API, data=parameters, headers=headers)

    print('\nRESPONSE++++++++++++++++++++++++++++++++++++')
    print('Response code: %d\n' % r.status_code)
    print(r.text)

# ************* SEND API *************

appId       = ''
token       = ''
mobile      = ''

#mobileQuery(appId, token)
#mobileValidate(appId, token, mobile)
#mobileWebValidate(appId, token, mobile)
